Errors
======

.. autoclass:: asyncdbus.DBusError
    :members:
    :undoc-members:

.. autoclass:: asyncdbus.SignatureBodyMismatchError
.. autoclass:: asyncdbus.InvalidSignatureError
.. autoclass:: asyncdbus.InvalidAddressError
.. autoclass:: asyncdbus.AuthError
.. autoclass:: asyncdbus.InvalidMessageError
.. autoclass:: asyncdbus.InvalidIntrospectionError
.. autoclass:: asyncdbus.InterfaceNotFoundError
.. autoclass:: asyncdbus.SignalDisabledError
.. autoclass:: asyncdbus.InvalidBusNameError
.. autoclass:: asyncdbus.InvalidObjectPathError
.. autoclass:: asyncdbus.InvalidInterfaceNameError
.. autoclass:: asyncdbus.InvalidMemberNameError
